@@ -28,8 +28,13 @@ function(data=NULL, model=NULL) {
 
     return(unlist(lapply(1:length(data$test), function(i) {
         sapply(1:nrow(data$test[[i]]), function(j) {
-            perfs = subset(data$test[[i]][j,], T, data$performance)
-            as.numeric(abs(perfs[which(data$performance == predictions[[i]][[j]]$algorithm[1])] - optfun(perfs)))
+                perfs = subset(data$test[[i]][j,], T, data$performance)
+                chosen = which(data$performance == predictions[[i]][[j]]$algorithm[1])
+                if(length(chosen) == 0) {
+                    NA
+                } else {
+                    as.numeric(abs(perfs[chosen] - optfun(perfs)))
+                }
             })
         })))
 }
