@@ -58,27 +58,31 @@ test_that("parscores allows to specify timeout", {
 
 test_that("parscores takes feature costs into account", {
     fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
-        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5))
-    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c"), features=c("c"))
+        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), c_cost=rep.int(2, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c_cost"), features=c("c"))
     as = rep.int(list(data.frame(algorithm="a", score=1)), 5)
     bs = rep.int(list(data.frame(algorithm="b", score=1)), 5)
     modela = list(predictions=list(as, as))
     modelb = list(predictions=list(bs, bs))
 
     expect_equal(sum(parscores(d, modela, timeout=1.5)), 150)
-    expect_equal(sum(parscores(d, modela, timeout=5)), 20)
-    expect_equal(sum(parscores(d, modelb, timeout=1.5)), 10)
+    expect_equal(sum(parscores(d, modela, timeout=5)), 30)
+    expect_equal(sum(parscores(d, modelb, timeout=2.5)), 20)
+
+    expect_equal(sum(parscores(d, modela, timeout=0.5, addCosts=F)), 50)
+    expect_equal(sum(parscores(d, modela, timeout=5, addCosts=F)), 10)
+    expect_equal(sum(parscores(d, modelb, timeout=2.5, addCosts=F)), 0)
 })
 
 test_that("parscores does not cost unused features", {
     fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
-        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), f=rep.int(1, 5))
-    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c", "f"), features=c("c"))
+        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), c_cost=rep.int(2, 5), f_cost=rep.int(1, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c_cost", "f_cost"), features=c("c"))
     as = rep.int(list(data.frame(algorithm="a", score=1)), 5)
     modela = list(predictions=list(as, as))
 
     expect_equal(sum(parscores(d, modela, timeout=1.5)), 150)
-    expect_equal(sum(parscores(d, modela, timeout=2.5)), 20)
+    expect_equal(sum(parscores(d, modela, timeout=3.5)), 30)
 })
 
 test_that("parscores takes feature cost groups into account", {
@@ -110,3 +114,14 @@ test_that("parscores works for test splits", {
 
     expect_equal(sum(parscores(d, model)), 50)
 })
+
+test_that("parscores works with NA predictions", {
+    fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
+        d=rep.int(F, 5), e=rep.int(T, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"))
+    nas = rep.int(list(data.frame(algorithm=NA, score=0)), 5)
+    as = rep.int(list(data.frame(algorithm="a", score=1)), 5)
+    model = list(predictions=list(nas, as))
+
+    expect_equal(sum(parscores(d, model), na.rm=T), 50)
+})
