@@ -32,8 +32,8 @@ test_that("successes works without test split", {
 
 test_that("sucesses takes feature costs into account", {
     fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
-        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5))
-    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c"), features=c("c"))
+        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), c_cost=rep.int(2, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c_cost"), features=c("c"))
     as = rep.int(list(data.frame(algorithm="a", score=1)), 5)
     bs = rep.int(list(data.frame(algorithm="b", score=1)), 5)
     modela = list(predictions=list(as, as))
@@ -41,18 +41,22 @@ test_that("sucesses takes feature costs into account", {
 
     expect_equal(sum(successes(d, modela, timeout=1.5)), 0)
     expect_equal(sum(successes(d, modela, timeout=5)), 10)
-    expect_equal(sum(successes(d, modelb, timeout=1.5)), 10)
+    expect_equal(sum(successes(d, modelb, timeout=2.5)), 10)
+
+    expect_equal(sum(successes(d, modela, timeout=1.5, addCosts=F)), 10)
+    expect_equal(sum(successes(d, modela, timeout=5, addCosts=F)), 10)
+    expect_equal(sum(successes(d, modelb, timeout=2.5, addCosts=F)), 10)
 })
 
 test_that("sucesses does not cost unused features", {
     fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
-        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), f=rep.int(1, 5))
-    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c", "f"), features=c("c"))
+        d=rep.int(T, 5), e=rep.int(T, 5), c=rep.int(1, 5), c_cost=rep.int(2, 5), f_cost=rep.int(1, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"), cost=c("c_cost", "f_cost"), features=c("c"))
     as = rep.int(list(data.frame(algorithm="a", score=1)), 5)
     modela = list(predictions=list(as, as))
 
     expect_equal(sum(successes(d, modela, timeout=1.5)), 0)
-    expect_equal(sum(successes(d, modela, timeout=2.5)), 10)
+    expect_equal(sum(successes(d, modela, timeout=3.5)), 10)
 })
 
 test_that("successes takes feature cost groups into account", {
@@ -83,3 +87,14 @@ test_that("successes works for test splits", {
 
     expect_equal(sum(successes(d, model)), 5)
 })
+
+test_that("successes works with NA predictions", {
+    fold = data.frame(a=rep.int(1, 5), b=rep.int(0, 5),
+        d=rep.int(F, 5), e=rep.int(T, 5))
+    d = list(data=rbind(fold, fold), test=list(fold, fold), performance=c("a", "b"), success=c("d", "e"))
+    nas = rep.int(list(data.frame(algorithm=NA, score=0)), 5)
+    as = rep.int(list(data.frame(algorithm="b", score=1)), 5)
+    model = list(predictions=list(nas, as))
+
+    expect_equal(sum(successes(d, model), na.rm=T), 5)
+})
